@@ -410,16 +410,16 @@ class Objeto():
     def borda_superior(self):
         borda_superior = self.area_da_imagem.copy()
         borda_superior.height = self.largura_da_borda
-        borda_superior.width -= 2 * self.largura_da_borda
-        borda_superior.left = self.esquerda + self.largura_da_borda
+        borda_superior.width -= 2
+        borda_superior.left = self.esquerda + 1
         return borda_superior
     
     @property
     def borda_inferior(self):
         borda_inferior = self.area_da_imagem.copy()
         borda_inferior.height = self.largura_da_borda
-        borda_inferior.width -= 2 * self.largura_da_borda
-        borda_inferior.left = self.esquerda + self.largura_da_borda
+        borda_inferior.width -= 2
+        borda_inferior.left = self.esquerda + 1
         borda_inferior.bottom = self.base
         return borda_inferior
     
@@ -427,16 +427,16 @@ class Objeto():
     def borda_esquerda(self):
         borda_esquerda = self.area_da_imagem.copy()
         borda_esquerda.width = self.largura_da_borda
-        borda_esquerda.height -= 2 * self.largura_da_borda
-        borda_esquerda.top = self.topo + self.largura_da_borda
+        borda_esquerda.height -= 2
+        borda_esquerda.top = self.topo + 1
         return borda_esquerda
     
     @property
     def borda_direita(self):
         borda_direita = self.area_da_imagem.copy()
         borda_direita.width = self.largura_da_borda
-        borda_direita.height -= 2 * self.largura_da_borda
-        borda_direita.top = self.topo + self.largura_da_borda
+        borda_direita.height -= 2
+        borda_direita.top = self.topo + 1
         borda_direita.right = self.direita
         return borda_direita
     
@@ -532,8 +532,7 @@ class Tela():
         self._altura = altura
         self.cor = cor
         self.fps = fps
-        self._tela = pygame.display.set_mode( [self.largura, self.altura] ) 
-    
+
     @property
     def largura(self):
         return self._largura
@@ -542,8 +541,9 @@ class Tela():
     def altura(self):
         return self._altura
         
-def atualizar_tela(largura, altura, cor, fps):
-    global rodar_threading
+def atualizar_tela():
+    global rodar_threading, tela
+    tela._tela = pygame.display.set_mode( [tela.largura, tela.altura] ) 
     while rodar_threading:
         pygame.time.Clock().tick( tela.fps)
                 
@@ -566,11 +566,7 @@ def atualizar_tela(largura, altura, cor, fps):
                 pygame.draw.rect( tela._tela, botao.cor, botao.rect )
 
         pygame.display.flip()
-
-def verificar_eventos():
-    global rodar_threading
-    while rodar_threading:
-        pygame.time.Clock().tick(500)
+        
         for event in pygame.event.get():
                 if event.type == pygame.QUIT:
                     #faz threadings fecharem
@@ -584,7 +580,8 @@ def verificar_eventos():
                     for acao in acoes_paralelas:
                         acao.join()
                     #espera threading da tela
-                    t_atualizar_tela.join()
+                    #t_atualizar_tela.join()
+                    pygame.display.quit()
                     #fecha a tela
                     pygame.quit()
                     #sai do programa
@@ -595,12 +592,12 @@ def verificar_eventos():
 def abrir_tela(largura=800, altura=600, cor = roxo, fps= 60):
     global tela, t_atualizar_tela
     tela = Tela(largura, altura, cor, fps)
-    t_atualizar_tela = threading.Thread( target= atualizar_tela,
-                                          args= (largura, altura, cor, fps))
+    t_atualizar_tela = threading.Thread( target= atualizar_tela )
     t_atualizar_tela.start()
 
-    t_verificar_eventos = threading.Thread( target= verificar_eventos )
-    t_verificar_eventos.start()
+    #t_verificar_eventos = threading.Thread( target= verificar_eventos )
+    #t_verificar_eventos.start()
+    return tela
 
 
 #Permite programar açoes para os objetos
@@ -651,3 +648,4 @@ esperar = time.sleep
 
 
 
+
